package xmlm

  1. Overview
  2. Docs

Module type Xmlm.StringSource

Input signature for strings.

Sourcetype t

The type for strings.

Sourceval empty : t

The empty string.

Sourceval length : t -> int

Returns the length of the string.

Sourceval append : t -> t -> t

Concatenates two strings.

Sourceval lowercase : t -> t

New string with uppercase letter translated to lowercase (correctness is only needed for ASCII code point).

Sourceval iter : (int -> unit) -> t -> unit

Iterates over the unicode code point of the given string.

Sourceval of_string : std_string -> t

String from an OCaml string.

Sourceval to_utf_8 : ('a -> std_string -> 'a) -> 'a -> t -> 'a

to_utf_8 f v s, is f (... (f (f v s1) s2) ...) sn. Where the concatenation of s1, s2, ... sn is s as an UTF-8 stream.

Sourceval compare : t -> t -> int

String comparison. Binary comparison is sufficent.