package xmlm
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Xmlm.StringSource
Input signature for strings.
The type for strings.
New string with uppercase letter translated to lowercase (correctness is only needed for ASCII code point).
Iterates over the unicode code point of the given string.
String from an OCaml string.
to_utf_8 f v s, is f (... (f (f v s1) s2) ...) sn. Where the concatenation of s1, s2, ... sn is s as an UTF-8 stream.